const ws = require("ws");
const express = require("express");
const { MAP_DATA } = require("./data/MapData");
const OWNER_DATA = require("./data/OwnerData");

const DEFAULT_COLORS = {
  WALL: "#000000",
  LAND: "#18e718",
  USER: "#0ec9eb",
};

const SOCKET_RESULT_TYPE = {
  MAP: "MAP",
  OWNER: "OWNER",
};

const OWNER_DATA_KEYS = {
  OWNER_DATA_1: "OWNER_DATA_1",
  OWNER_DATA_2: "OWNER_DATA_2",
  OWNER_DATA_3: "OWNER_DATA_3",
  OWNER_DATA_4: "OWNER_DATA_4",
  OWNER_DATA_5: "OWNER_DATA_5",
  OWNER_DATA_6: "OWNER_DATA_6",
  OWNER_DATA_7: "OWNER_DATA_7",
  OWNER_DATA_8: "OWNER_DATA_8",
  OWNER_DATA_9: "OWNER_DATA_9",
  OWNER_DATA_10: "OWNER_DATA_10",
};

const selectFromOwnerData = () => {
  const keys = Object.keys(OWNER_DATA_KEYS);
  const randomIdx = Math.floor(Math.random() * keys.length);
  return OWNER_DATA[keys[randomIdx]];
};

const app = express();

const wsServer = new ws.Server({ noServer: true });

wsServer.on("connection", (socket) => {
  socket.send(
    JSON.stringify({
      type: SOCKET_RESULT_TYPE.MAP,
      result: MAP_DATA,
    })
  );
  socket.send(
    JSON.stringify({
      type: SOCKET_RESULT_TYPE.OWNER,
      result: OWNER_DATA.OWNER_DATA_1,
    })
  );

  socket.on("message", function message(data) {
    const result = JSON.parse(data);
    socket.send(
      JSON.stringify({
        type: SOCKET_RESULT_TYPE.OWNER,
        result: [
          {
            compony: "USER",
            color: DEFAULT_COLORS.USER,
            startCord: {
              x: result.x,
              y: result.y,
            },
            endCord: {
              x: result.x,
              y: result.y,
            },
          },
        ],
      })
    );
  });

  setInterval(() => {
    socket.send(
      JSON.stringify({
        type: SOCKET_RESULT_TYPE.OWNER,
        result: selectFromOwnerData(),
      })
    );
  }, 10000);
});

const server = app.listen(3001);
server.on("upgrade", (request, socket, head) => {
  wsServer.handleUpgrade(request, socket, head, (socket) => {
    wsServer.emit("connection", socket, request);
  });
});
